@@ -243,7 +243,10 @@ function parseFriendsCheckins(response) {
             venueName = checkin.venue.name;
             venueID = checkin.venue.id;
         }
-        var comments = parse(checkin.comments.count);
+        var comments = 0;
+        if (typeof(checkin.comments)!="undefined") {
+            comments = parse(checkin.comments.count);
+        }
         var venuePhoto = "";
         if (checkin.photos.count > 0) {
             venuePhoto = thumbnailPhoto(checkin.photos.items[0], 300);
